@@ -18,8 +18,8 @@ DEFAULTS = {
             "weight": {},
             "conc_met_bounds": (1e-06, 50),
             "flux_met_bounds": (-50, 50),
-            "conc_biom_bounds": (1e-03, 50),
-            "flux_biom_bounds": (1e-4, 2),
+            "conc_biom_bounds": (1e-03, 10),
+            "flux_biom_bounds": (1e-3, 3),
             "t_lag": 0,
             "deg": {},
             "iterations": 100
@@ -67,7 +67,7 @@ class IoHandler:
 
         data_path = Path(path_to_data).resolve()
 
-        if data_path.suffix == ".tsv":
+        if data_path.suffix in [".txt", ".tsv"]:
             data = read_csv(str(data_path), sep="\t")
         elif data_path.suffix == ".csv":
             data = read_csv(str(data_path), sep=";")
@@ -75,7 +75,7 @@ class IoHandler:
             if not data_path.exists():
                 raise ValueError(f"{data_path} is not a valid file")
             else:
-                raise TypeError(f"{data_path} is not a valid format. Accepted formats are .csv or .tsv")
+                raise TypeError(f"{data_path} is not a valid format. Accepted formats are .csv, .txt or .tsv")
 
         IoHandler._verify_data(data)
         return data
@@ -333,7 +333,13 @@ class IoHandler:
         self.fitter = PhysioFitter(self.data)
 
         # Initialize fitter logger
-        file_handle = logging.FileHandler(self.res_path / "log.txt", "w+")
+        if self.res_path is not None:
+            try:
+                file_handle = logging.FileHandler(self.res_path / "log.txt", "w+")
+            except:
+                raise ValueError("An error has occurred while initializing the log file. Please check the 'Output data directory'.")
+        else:
+            raise ValueError("Please select an 'Output data directory'.")
         try:
             if kwargs["debug_mode"]:
                 file_handle.setLevel(logging.DEBUG)
